# dCRE
Computation and decomposition of Cloud Radiative Effects (CRE)

![ci.yaml](https://github.com/observingClouds/dCRE/actions/workflows/ci.yaml/badge.svg)

> [!WARNING]
> This package is still under development. Things will break.
